@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: apr 27 2018 (23:32) 
 ## Version: 
-## Last-Updated: jan  8 2019 (09:24) 
+## Last-Updated: nov 13 2019 (09:25) 
 ##           By: Brice Ozenne
-##     Update #: 117
+##     Update #: 188
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -20,19 +20,21 @@
 ##' @description Check the validity of the argument passed the BuyseTest function by the user.
 ##'
 ##' @keywords internal
-testArgs <- function(alternative,
-                     name.call,
+testArgs <- function(name.call,
                      censoring,
                      correction.uninf,
                      cpus,
                      data,
                      endpoint,
                      formula,
+                     iid,
                      keep.pairScore,
-                     method.tte,
+                     scoring.rule,
                      model.tte,
                      method.inference,
                      n.resampling,
+                     strata.resampling,
+                     hierarchical,
                      neutral.as.uninf,
                      operator,
                      seed,
@@ -41,26 +43,27 @@ testArgs <- function(alternative,
                      trace,
                      treatment,
                      type,
+                     weight,
                      ...){
 
     ## ** data
     if (!data.table::is.data.table(data)) {
         if(inherits(data,"function")){
-            stop("Argument \'data\' is mispecified \n",
-                 "\'data\' cannot be a function \n")
+            stop("Argument \'data\' is mispecified. \n",
+                 "\'data\' cannot be a function. \n")
         }
         data <- data.table::as.data.table(data)
     }else{
         data <- data.table::copy(data)
     }
     if("..rowIndex.." %in% names(data)){
-        stop("BuyseTest: Argument \'data\' must not contain a column \"..rowIndex..\" \n")
+        stop("BuyseTest: Argument \'data\' must not contain a column \"..rowIndex..\". \n")
     }
     if("..NA.." %in% names(data)){
-        stop("BuyseTest: Argument \'data\' must not contain a column \"..NA..\" \n")
+        stop("BuyseTest: Argument \'data\' must not contain a column \"..NA..\". \n")
     }
     if("..strata.." %in% names(data)){
-        stop("BuyseTest: Argument \'data\' must not contain a column \"..strata..\" \n")
+        stop("BuyseTest: Argument \'data\' must not contain a column \"..strata..\". \n")
     }
     
     ## ** extract usefull quantities
@@ -82,31 +85,25 @@ testArgs <- function(alternative,
     }
 
     
-    ## ** alternative
-    validCharacter(alternative,
-                   valid.length = 1,
-                   valid.values = c("two.sided", "less", "greater"),
-                   method = "BuyseTest")
-
     ## ** censoring
     if(length(censoring) != D){
-        stop("BuyseTest: \'censoring\' does not match \'endpoint\' size \n",
-             "length(censoring) : ",length(censoring),"\n",
+        stop("BuyseTest: \'censoring\' does not match \'endpoint\' size. \n",
+             "length(censoring): ",length(censoring),"\n",
              "length(endpoint) : ",D,"\n")
             
     }
     if(any(is.na(censoring))){
-        stop("BuyseTest: \'censoring\' must not contain NA \n")
+        stop("BuyseTest: \'censoring\' must not contain NA. \n")
     }
     if(any(censoring[type==3] == "..NA..") ){
-        stop("BuyseTest: wrong specification of \'censoring\' \n",
-             "\'censoring\' must indicate a variable in data for TTE endpoints \n",
-             "TTE endoints : ",paste(endpoint[type==3],collapse=" "),"\n",
-             "proposed \'censoring\' for these endoints : ",paste(censoring[type==3],collapse=" "),"\n")
+        stop("BuyseTest: wrong specification of \'censoring\'. \n",
+             "\'censoring\' must indicate a variable in data for TTE endpoints. \n",
+             "TTE endoints: ",paste(endpoint[type==3],collapse=" "),"\n",
+             "proposed \'censoring\' for these endoints: ",paste(censoring[type==3],collapse=" "),"\n")
     }
     if(any(censoring[type!=3] !="..NA..") ){
-        stop("BuyseTest: wrong specification of \'censoring\' \n",
-             "\'censoring\' must be \"..NA..\" for binary or continuous endpoints \n",
+        stop("BuyseTest: wrong specification of \'censoring\'. \n",
+             "\'censoring\' must be \"..NA..\" for binary or continuous endpoints. \n",
              "endoints : ",paste(endpoint[type!=3],collapse=" "),"\n",
              "proposed \'censoring\' for these endoints : ",paste(censoring[type!=3],collapse=" "),"\n")
     }
@@ -120,11 +117,11 @@ testArgs <- function(alternative,
                      method = "BuyseTest")
     }
 
-    ## ** method.tte
+    ## ** scoring.rule
     ## must be before time to event endpoints
-    if(is.na(method.tte)){
-        stop("BuyseTest: wrong specification of \'method.tte\' \n",
-             "valid values: \"Gehan\" \"Gehan corrected\" \"Peron\" \"Peron corrected\" \n")
+    if(is.na(scoring.rule)){
+        stop("BuyseTest: wrong specification of \'scoring.rule\'. \n",
+             "valid values: \"Gehan\" \"Gehan corrected\" \"Peron\" \"Peron corrected\". \n")
     }
 
     ## ## ** model.tte
@@ -132,24 +129,24 @@ testArgs <- function(alternative,
         endpoint.UTTE <- unique(endpoint[type==3])
         D.UTTE <- length(endpoint.UTTE)
         if(!is.list(model.tte) || length(model.tte) != D.UTTE){
-            stop("BuyseTest: argument \'model.tte\' must be a list containing ",D.UTTE," elements \n",
-                 "(one for each unique time to event endpoint) \n")
+            stop("BuyseTest: argument \'model.tte\' must be a list containing ",D.UTTE," elements. \n",
+                 "(one for each unique time to event endpoint). \n")
         }
 
         if(is.null(model.tte) || any(names(model.tte) != endpoint.UTTE)){
-            stop("BuyseTest: argument \'model.tte\' must be a named list \n",
+            stop("BuyseTest: argument \'model.tte\' must be a named list. \n",
                  "valid sequence of names: \"",paste0(endpoint.UTTE, collapse = "\" \""),"\" \n",
                  "proposed names: \"",paste0(names(model.tte), collapse = "\" \""),"\" \n")
         }
 
         vec.class  <- sapply(model.tte, function(iTTE){inherits(iTTE, "prodlim")})
         if(any(vec.class == FALSE) ){
-            stop("BuyseTest: argument \'model.tte\' must be a list of \"prodlim\" objects \n")
+            stop("BuyseTest: argument \'model.tte\' must be a list of \"prodlim\" objects. \n")
         }
 
         vec.predictors  <- sapply(model.tte, function(iTTE){identical(sort(iTTE$discrete.predictors), sort(c(treatment,strata)))})
         if(any(vec.predictors == FALSE) ){
-            stop("BuyseTest: argument \'model.tte\' must be a list of \"prodlim\" objects with \"",paste0(c(treatment,strata),collapse = "\" \""),"\" as predictors \n")
+            stop("BuyseTest: argument \'model.tte\' must be a list of \"prodlim\" objects with \"",paste0(c(treatment,strata),collapse = "\" \""),"\" as predictors. \n")
         }        
     }
     
@@ -160,7 +157,7 @@ testArgs <- function(alternative,
     if(length(index.Bin)>0){
         for(iBin in index.Bin){ ## iterY <- 1
             if(length(unique(na.omit(data[[endpoint[iBin]]])))>2){
-                stop("Binary endpoint cannot have more than 2 levels \n",
+                stop("Binary endpoint cannot have more than 2 levels. \n",
                      "endpoint: ",endpoint[iBin],"\n")
             }
             ## if(any(is.na(data[[endpoint[iBin]]]))){                
@@ -196,11 +193,8 @@ testArgs <- function(alternative,
                    refuse.NULL = FALSE,
                    method = "BuyseTest")
 
-        if(method.tte==0){ ## Gehan
-            valid.values.censoring <- 0:2
-        }else if(method.tte==1){ ## Peron
-            valid.values.censoring <- 0:1
-        }
+        valid.values.censoring <- 0:2
+
         for(iTTE in index.TTE){
             validNumeric(data[[endpoint[iTTE]]],
                          name1 = endpoint[iTTE],
@@ -217,6 +211,7 @@ testArgs <- function(alternative,
 
     ## ** endpoint
     validNames(data,
+               name1 = "data",
                required.values = endpoint,
                valid.length = NULL,
                method = "BuyseTest")
@@ -224,8 +219,8 @@ testArgs <- function(alternative,
     ## ** formula
     if(!is.null(formula) && any(name.call %in% argnames)){
         txt <- paste(name.call[name.call %in% argnames], collapse = "\' \'")
-        warning("BuyseTest: argument",if(length(txt)>1){"s"}," \'",txt,"\' ha",if(length(txt)>1){"ve"}else{"s"}," been ignored \n",
-                "when specified, only argument \'formula\' is used \n")
+        warning("BuyseTest: argument",if(length(txt)>1){"s"}," \'",txt,"\' ha",if(length(txt)>1){"ve"}else{"s"}," been ignored. \n",
+                "when specified, only argument \'formula\' is used. \n")
     }
 
     ## ** keep.pairScore
@@ -239,11 +234,30 @@ testArgs <- function(alternative,
                  method = "BuyseTest")
 
     ## ** method.inference
-    validCharacter(method.inference,
-                   valid.length = 1,
-                   valid.values = c("none","asymptotic","asymptotic-bebu","bootstrap","permutation","stratified bootstrap","stratified permutation"),
-                   method = "BuyseTest")
-
+    if(length(method.inference)!=1){
+        stop("Argument \'method.inference\' must have length 1. \n")
+    }
+    if(method.inference != "u-statistic-bebu"){ ## asympototic bebu - hidden value only for debugging
+        validCharacter(method.inference,
+                       valid.length = 1,
+                       valid.values = c("none","u-statistic","permutation","bootstrap","studentized bootstrap"),
+                       method = "BuyseTest")
+    }
+    if(method.inference != "none" && any(table(data[[treatment]])<2) ){
+        warning("P-value/confidence intervals will not be valid with only one observation. \n")
+    }
+    if(!is.na(attr(method.inference,"resampling-strata")) && any(attr(method.inference,"resampling-strata") %in% names(data) == FALSE)){
+        stop("Incorrect value for argument \'strata.resampling\': must correspond to a column in argument \'data\'. \n")
+    }
+    if(!is.na(attr(method.inference,"resampling-strata")) && attr(method.inference,"permutation") && any(attr(method.inference,"resampling-strata") == treatment)){
+        stop("Argument \'strata.resampling\' should not contain the variable used to form the treatment groups when using a permutation test. \n")
+    }
+    if(iid && correction.uninf > 0){
+        warning("The current implementation of the asymptotic distribution has not been validated when using a correction. \n",
+                "Standard errors / confidence intervals / p-values may not be correct. \n",
+                "Consider using a resampling approach or checking the control of the type 1 error with powerBuyseTest. \n")
+    }
+    
     ## ** n.resampling
     if(method.inference %in% c("bootstrap","permutation","stratified bootstrap","stratified permutation")){
         validInteger(n.resampling,
@@ -252,6 +266,11 @@ testArgs <- function(alternative,
                      method = "BuyseTest")
     }
     
+   ## ** hierarchical
+    validLogical(hierarchical,
+                 valid.length = 1,
+                 method = "BuyseTest")
+
     ## ** neutral.as.uninf
     validLogical(neutral.as.uninf,
                  valid.length = 1,
@@ -265,7 +284,7 @@ testArgs <- function(alternative,
 
     n.operatorPerEndpoint <- tapply(operator, endpoint, function(x){length(unique(x))})
     if(any(n.operatorPerEndpoint>1)){
-        stop("Cannot have different operator for the same endpoint used at different priorities \n")
+        stop("Cannot have different operator for the same endpoint used at different priorities. \n")
     }
 
     ## ** seed
@@ -279,14 +298,14 @@ testArgs <- function(alternative,
      ## ** strata
     if (!is.null(strata)) {
         validNames(data,
-                   name1 = "strata",
+                   name1 = "data",
                    required.values = strata,
                    valid.length = NULL,
                    method = "BuyseTest")
 
        
         if(length(level.strata) != length(levels(strataC)) || any(level.strata != levels(strataC))){
-            stop("BuyseTest: wrong specification of \'strata\' \n",
+            stop("BuyseTest: wrong specification of \'strata\'. \n",
                  "different levels between Control and Treatment \n",
                  "levels(strataT) : ",paste(levels(strataT),collapse=" "),"\n",
                  "levels(strataC) : ",paste(levels(strataC),collapse=" "),"\n")
@@ -303,7 +322,7 @@ testArgs <- function(alternative,
 
     ## check threshold at 1/2 for binary endpoints
     if(any(threshold[type==1]!=1/2)){
-        stop("BuyseTest: wrong specification of \'threshold\' \n",
+        stop("BuyseTest: wrong specification of \'threshold\'. \n",
              "\'threshold\' must be 1/2 for binary endpoints (or equivalently NA) \n",
              "proposed \'threshold\' : ",paste(threshold[type==1],collapse=" "),"\n",
              "binary endpoint(s) : ",paste(endpoint[type==1],collapse=" "),"\n")
@@ -320,9 +339,9 @@ testArgs <- function(alternative,
     })
     
     if(any(vec.test>0)){   
-        stop("BuyseTest: wrong specification of \'endpoint\' or \'threshold\' \n",
-             "endpoints must be used with strictly decreasing threshold when re-used with lower priority \n",
-             "problematic endpoints: \"",paste0(names(vec.test)[vec.test>0], collapse = "\" \""),"\"\n")        
+        stop("BuyseTest: wrong specification of \'endpoint\' or \'threshold\'. \n",
+             "Endpoints must be used with strictly decreasing threshold when re-used with lower priority. \n",
+             "Problematic endpoints: \"",paste0(names(vec.test)[vec.test>0], collapse = "\" \""),"\"\n")        
     }
 
     ## ** trace
@@ -337,20 +356,21 @@ testArgs <- function(alternative,
                    method = "BuyseTest")
 
     validNames(data,
+               name1 = "data",          
                required.values = treatment,
                valid.length = NULL,
                method = "BuyseTest")
 
     if (length(level.treatment) != 2) {
-        stop("BuyseTest: wrong specification of \'treatment\' \n",
-             "the corresponding column in \'data\' must have exactly 2 levels \n",
-             "proposed levels : ",paste(level.treatment,collapse = " "),"\n")
+        stop("BuyseTest: wrong specification of \'treatment\'. \n",
+             "The corresponding column in \'data\' must have exactly 2 levels. \n",
+             "Proposed levels : ",paste(level.treatment,collapse = " "),"\n")
     }
 
     if(any(table(data[[treatment]])==0)){
         txt.stop <- names(which(table(data[[treatment]])==0))
-        stop("BuyseTest: wrong specification of \'data\' \n",
-             "no observation taking level ",txt.stop," in the treatment variable \n")
+        stop("BuyseTest: wrong specification of \'data\'. \n",
+             "No observation taking level ",txt.stop," in the treatment variable. \n")
         
     }
     
@@ -369,6 +389,17 @@ testArgs <- function(alternative,
                           "\n")        
         stop("BuyseTest: wrong specification of \'endpoint\' or \'type\' \n",message)
     }
+
+    ## ** weight
+    if(length(weight) != D){
+            stop("BuyseTest: argument \'weight\' must have length the number of endpoints \n")
+    }
+    
+    if(hierarchical){
+        if(any(weight!=1) || any(is.na(weight))){
+            stop("BuyseTest: all the weights must be 1 when using hierarchical GPC \n")
+        }
+    }
     
     ## ** export
     return(invisible(TRUE))
