@@ -12,9 +12,10 @@ printGeneral <- function(censoring,
                          D.TTE,
                          data,
                          endpoint,
+                         hierarchical,
                          level.strata,
                          level.treatment,
-                         method.tte,
+                         scoring.rule,
                          neutral.as.uninf,
                          correction.uninf,
                          operator,
@@ -23,10 +24,10 @@ printGeneral <- function(censoring,
                          trace,
                          treatment,
                          type,
+                         weight,
                          Wscheme,
                          ...){
 
-
     if(!is.null(strata)){
         n.strata <- length(level.strata)
     }else{
@@ -35,19 +36,23 @@ printGeneral <- function(censoring,
 
     ## ** Prepare
     ## endpoint
-    name.col <- c("priority", "endpoint","type","operator","threshold","censoring")
+    name.col <- c("NA", "endpoint","type","operator","threshold","censoring")
     df.endpoint <- data.frame(matrix(NA, nrow = D, ncol = 6,
                                      dimnames = list(NULL, name.col)
                                      ))
-    df.endpoint[,1] <- paste0("      ",1:D)
-    names(df.endpoint)[1] <- "      priority"
+    if(hierarchical){
+        df.endpoint[,1] <- paste0("      ",1:D)
+        names(df.endpoint)[1] <- "      priority"
+    }else{
+        df.endpoint[,1] <- paste0("      ",weight)
+        names(df.endpoint)[1] <- "      weight"
+    }
     df.endpoint$endpoint <- endpoint
     df.endpoint$type <- c("binary","continuous","time to event")[type]
     df.endpoint$operator <- c("lower is favorable","higher is favorable")[1 + (operator == ">0")]
     df.endpoint$threshold[type!=1] <- threshold[type!=1]
     df.endpoint$censoring[type==3] <- censoring[type==3]
 
-    df.endpoint[is.na(df.endpoint)] <- ""
     ## add white space
     df.endpoint$endpoint <- paste0(df.endpoint$endpoint," ")
     df.endpoint$type <- paste0(df.endpoint$type," ")
@@ -63,31 +68,32 @@ printGeneral <- function(censoring,
     
     ## ** Display
     cat("Settings \n")
-    cat("   - treatment groups: Control = ",level.treatment[1]," and Treatment = ",level.treatment[2],"\n", sep = "")
+    cat("   - 2 groups  ",if(D>1){" "},": Control = ",level.treatment[1]," and Treatment = ",level.treatment[2],"\n", sep = "")
     cat("   - ",D," endpoint",if(D>1){"s"},": \n", sep = "")
     print(df.endpoint, row.names = FALSE, quote = FALSE, right = FALSE)
     if(n.strata>1){
         txt.variable <- switch(as.character(length(strata)),
-                               "0" = " variable",
+                               "1" = "variable",
                                "variables")        
-        cat("   - ", n.strata, " strata with levels: ",paste(level.strata, collapse = " ") , "\n", sep = "")
-        cat("                ",txt.variable,": ",paste(strata, collapse = " ")," \n", sep = "")
+        cat("   - ", n.strata, " strata   : levels ",paste(level.strata, collapse = " ") , " (",txt.variable,": ",paste(strata, collapse = " "),") \n", sep = "")
     }
-    cat("   - management of neutral pairs: ")
-    if(neutral.as.uninf){
-        cat("re-analyzed using endpoints of lower priority (if any) \n")
-    }else{
-        cat("ignore endpoints of lower priority \n")
+    if(D>1){
+        cat("   - neutral pairs: ")
+        if(neutral.as.uninf){
+            cat("re-analyzed using lower priority endpoints \n")
+        }else{
+            cat("ignored at lower priority endpoints \n")
+        }
     }
     if(D.TTE>0){
-        cat("   - management of censored survival pairs: ")
-        switch(as.character(method.tte),
-               "0" = cat("uninformative pairs \n"),
-               "1" = cat("use Kaplan Meier survival curves to compute the score \n")
+        cat("   - right-censored pairs: ")
+        switch(as.character(scoring.rule),
+               "0" = cat("deterministic score or uninformative \n"),
+               "1" = cat("probabilistic score based on the survival curves \n")
                )
     }
     ## if(trace>2){
-    ##     if ( (method.tte == "3" || correction.uninf) && D > 1) {            
+    ##     if ( (scoring.rule == "3" || correction.uninf) && D > 1) {            
     ##         cat("   - Current contribution of a pair based on the weights computed at previous enpoints: \n")
     ##         print(Wscheme)
     ##     }
@@ -100,19 +106,28 @@ printGeneral <- function(censoring,
 #' @rdname internal-print
 printInference <- function(method.inference, n.resampling, cpus, seed, ...){
 
-    txt.type <- switch(method.inference,
-                       "asymptotic" = "moments of the U-statistic",
-                       "bootstrap" = paste0("non parametric bootstrap with ",n.resampling," samples"),
-                       "stratified bootstrap" = paste0("stratified non-parametric bootstrap with ",n.resampling," samples"),
-                       "permutation" = paste0("permutation test with ", n.resampling, " permutations"),
-                       "stratified permutation" = paste0("stratified permutation test with ", n.resampling, " permutations"))
+    if(method.inference != "none"){
 
-    cat("Estimation of the asymptotic distribution \n",
-        "   - method: ",txt.type,"\n", sep = "")
-    if(method.inference != "asymptotic"){
-        cat("   - cpus  : ",cpus,"\n", sep = "")
-        if (!is.null(seed)) {
-            cat("   - seeds : ",paste(seq(seed,seed + cpus - 1), collapse = " "),"\n", sep = "")       
+        ## method        
+        if(attr(method.inference,"ustatistic")){
+            txt.type <- "moments of the U-statistic"
+        }else if(attr(method.inference,"bootstrap")){
+            txt.type <- paste0("non-parametric bootstrap with ",n.resampling," samples")
+        }else if(attr(method.inference,"permutation")){
+            txt.type <- paste0("permutation test with ",n.resampling," permutations")
+        }
+        if(!is.na(attr(method.inference,"resampling-strata"))){
+            txt.type <- paste0(txt.type, " (stratified by \"",paste(attr(method.inference,"resampling-strata"),sep="\" \""),"\")")
+        }
+
+        ## display
+        cat("Estimation of the estimator's distribution \n",
+            "   - method: ",txt.type,"\n", sep = "")
+        if(!attr(method.inference,"ustatistic")){
+            cat("   - cpus  : ",cpus,"\n", sep = "")
+            if (!is.null(seed)) {
+                cat("   - seeds : ",paste(seq(seed,seed + cpus - 1), collapse = " "),"\n", sep = "")       
+            }
         }
     }
 
