@@ -22,23 +22,31 @@ setClass(
       alternative = "character",
       check = "logical",
       conf.level = "numeric",
-      continuity.correction = "logical",
-      correction.uninf = "logical",
+      correction.uninf = "numeric",
       cpus = "numeric",
+      debug = "numeric",
+      hierarchical = "logical",
       keep.pairScore = "logical",
-      keep.survival = "logical",
+      keep.survival = "logical",      
       method.inference = "character",
-      method.tte = "character",
+      scoring.rule = "character",
       n.resampling = "numeric",
+      strata.resampling = "character",
       neutral.as.uninf = "logical",
       order.Hprojection = "numeric",
+      print.display = "character",
       statistic = "character",
+      summary.display = "list",
       trace = "numeric",
       transformation = "logical"
   ),
 
 ### ** Check validity of the object
   validity = function(object){
+      validNames.summary <- c("endpoint","threshold","weight","total","favorable","unfavorable","neutral","uninf","information(%)",
+                              "delta","Delta","Delta(%)",
+                              "p.value","CI","significance")
+      
       validCharacter(object@alternative,
                      name1 = "@alternative",
                      valid.values = c("two.sided","greater","less"),
@@ -54,8 +62,10 @@ setClass(
                    max = 1,
                    valid.length = 1,
                    method = "Class BuyseTest.options")
-      validLogical(object@correction.uninf,
+      validInteger(object@correction.uninf,
                    name1 = "@correction.uninf",
+                   min = 0,
+                   max = 2,
                    valid.length = 1,
                    method = "Class BuyseTest.options")
       validInteger(object@cpus,
@@ -63,6 +73,14 @@ setClass(
                    min = 1,
                    valid.length = 1,
                    method = "Class BuyseTest.options")
+      validInteger(object@debug,
+                   name1 = "@debug",
+                   valid.length = 1,
+                   method = "Class BuyseTest.options")
+      validLogical(object@hierarchical,
+                   name1 = "@hierarchical",
+                   valid.length = 1,
+                   method = "Class BuyseTest.options")
       validLogical(object@keep.pairScore,
                    name1 = "@keep.pairScore",
                    valid.length = 1,
@@ -73,13 +91,13 @@ setClass(
                    method = "Class BuyseTest.options")
       validCharacter(object@method.inference,
                      name1 = "@resampling",
-                     valid.values = c("bootstrap", "stratified boostrata",
+                     valid.values = c("bootstrap", "stratified bootstrap", "studentized bootstrap", "studentized stratified bootstrap",
                                       "permutation", "stratified permutation",
-                                      "asymptotic"),
+                                      "none", "u-statistic", "u-statistic-bebu"),
                      valid.length = 1,
                      method = "Class BuyseTest.options")
-      validCharacter(object@method.tte,
-                     name1 = "@method.tte",
+      validCharacter(object@scoring.rule,
+                     name1 = "@scoring.rule",
                      valid.values = c("Gehan","Peron"),
                      valid.length = 1,
                      method = "Class BuyseTest.options")
@@ -88,6 +106,11 @@ setClass(
                    min = 0,
                    valid.length = 1,
                    method = "Class BuyseTest.options")
+      validCharacter(object@strata.resampling,
+                   name1 = "@n.resampling",
+                   valid.values = c(as.character(NA),"treatment","strata"),
+                   valid.length = 1,
+                   method = "Class BuyseTest.options")
       validLogical(object@neutral.as.uninf,
                    name1 = "@neutral.as.uninf",
                    valid.length = 1,
@@ -98,11 +121,21 @@ setClass(
                    max = 2,
                    valid.length = 1,
                    method = "Class BuyseTest.options")
+      validCharacter(object@print.display,
+                     name1 = "@print.display",
+                     valid.values = validNames.summary,
+                     valid.length = NULL,
+                     method = "Class BuyseTest.options")
       validCharacter(object@statistic,
                      name1 = "@statistic",
                      valid.values = c("netBenefit","winRatio"),
                      valid.length = 1,
                      method = "Class BuyseTest.options")
+      lapply(object@summary.display,validCharacter,
+             name1 = "@summary.display",
+             valid.values = validNames.summary,
+             valid.length = NULL,
+             method = "Class BuyseTest.options")
       validInteger(object@trace,
                    name1 = "@trace",
                    min = 0, max = 2,
@@ -134,13 +167,13 @@ setMethod(f = "alloc",
             name.field <- names(field)
             n.field <- length(field)
             
-            for (iField in 1:n.field) {
-              slot(object, name.field[iField]) <- field[[iField]]
-            }
-            
-            return(object)
+              for (iField in 1:n.field) {
+                  slot(object, name.field[iField]) <- field[[iField]]
+              }
+              validObject(object)
+              return(object)
           }
-)
+          )
 
 ## * Select BuyseTest.options
 #' @rdname BuyseTest.options-methods
