@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: mar 30 2018 (13:17) 
 ## Version: 
-## Last-Updated: okt 30 2018 (16:33) 
+## Last-Updated: nov  6 2019 (14:12) 
 ##           By: Brice Ozenne
-##     Update #: 151
+##     Update #: 157
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -18,6 +18,7 @@
 if(FALSE){
     library(testthat)
     library(BuyseTest)
+    library(data.table)
 }
 
 context("Check BuyseTest on simple examples")
@@ -30,11 +31,10 @@ BuyseTest.options(check = TRUE,
 
 ## * one binary endpoint
 ## ** favorable
-test_that("check favorable - 1 Binary",{
-    
+test_that("check favorable - 1 Binary",{    
     ## one pair
-    data <- data.frame(toxicity1 = c(1,0), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data=data)
+    data <- data.frame(toxicity1 = c(1,0), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data=data)
     expect_equal(as.double(BT@count.favorable),1)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -43,7 +43,7 @@ test_that("check favorable - 1 Binary",{
 
     ## several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data2)
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data = data2)
     expect_equal(as.double(BT@count.favorable),4)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -52,20 +52,19 @@ test_that("check favorable - 1 Binary",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ bin(toxicity1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(4,4))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(0,0))
     expect_equal(as.double(BT@count.uninf),c(0,0))
     ## getPairScore(BT)
-
 })
 
 ## ** unfavorable
 test_that("check unfavorable - 1 Binary",{
     ## one pair
-    data <- data.frame(toxicity1 = c(0,1), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data)
+    data <- data.frame(toxicity1 = c(0,1), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),1)
     expect_equal(as.double(BT@count.neutral),0)
@@ -73,7 +72,7 @@ test_that("check unfavorable - 1 Binary",{
 
     ## several pairs
     data2 <- rbind(data,data)
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data2)
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),4)
     expect_equal(as.double(BT@count.neutral),0)
@@ -81,20 +80,19 @@ test_that("check unfavorable - 1 Binary",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ bin(toxicity1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(4,4))
     expect_equal(as.double(BT@count.neutral),c(0,0))
     expect_equal(as.double(BT@count.uninf),c(0,0))
     ## getPairScore(BT)
-
 })
 
 ## ** neutral
 test_that("check neutral - 1 Binary",{
     ## 1 pair
-    data <- data.frame(toxicity1 = c(1,1), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data)
+    data <- data.frame(toxicity1 = c(1,1), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),1)
@@ -102,7 +100,7 @@ test_that("check neutral - 1 Binary",{
 
     ## several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data2)
+    BT <- BuyseTest(treatment ~ bin(toxicity1), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),4)
@@ -110,7 +108,7 @@ test_that("check neutral - 1 Binary",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ bin(toxicity1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
@@ -120,8 +118,8 @@ test_that("check neutral - 1 Binary",{
 
 ## ** NA as uninformative
 test_that("check NA - 1 Binary",{
-  data <- data.frame(toxicity1 = c(NA, 1, 1), Treatment = c(1, 1, 0))
-  BT <- BuyseTest(Treatment ~ bin(toxicity1), data = data)
+  data <- data.frame(toxicity1 = c(NA, 1, 1), treatment = c(1, 1, 0))
+  BT <- BuyseTest(treatment ~ bin(toxicity1), data = data)
   expect_equal(as.double(BT@count.favorable),0)
   expect_equal(as.double(BT@count.unfavorable),0)
   expect_equal(as.double(BT@count.neutral),1)
@@ -129,7 +127,7 @@ test_that("check NA - 1 Binary",{
 
   ## with strata
   data2 <- rbind(cbind(data, strata = 0), cbind(data, strata = 1))
-  BT <- BuyseTest(Treatment ~ bin(toxicity1) + strata, data = data2)
+  BT <- BuyseTest(treatment ~ bin(toxicity1) + strata, data = data2)
   expect_equal(as.double(BT@count.favorable),c(0,0))
   expect_equal(as.double(BT@count.unfavorable),c(0,0))
   expect_equal(as.double(BT@count.neutral),c(1,1))
@@ -139,13 +137,12 @@ test_that("check NA - 1 Binary",{
 ## * two binary endpoints
 ## ** unfavorable
 test_that("check unfavorable - 2 Binary",{
-    dt <- data.table(Treatment = 1:2,
+    dt <- data.table(treatment = 1:2,
                      toxicity1 = 0,
                      toxicity2 = c(1,0),
                      Id = 1:10)
-    BT <- BuyseTest(Treatment ~ bin(toxicity1) + bin(toxicity2), data = dt)
-    ## getPairScore(BT)
-
+    BT <- BuyseTest(treatment ~ bin(toxicity1) + bin(toxicity2), data = dt)
+    
     ## total pairs: 25
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,25))
@@ -161,13 +158,13 @@ test_that("check unfavorable - 2 Binary",{
 
 ## ** mixed
 test_that("check mixed - 2 Binary",{
-    dt <- data.table(Treatment = c(1,1,2,2),
+    dt <- data.table(treatment = c(1,1,2,2),
                      toxicity1 = 0,
                      toxicity2 = c(1,0,1,0))
-    BT <- BuyseTest(Treatment ~ bin(toxicity1) + bin(toxicity2), data = dt,
+    BT <- BuyseTest(treatment ~ bin(toxicity1) + bin(toxicity2), data = dt,
                     keep.pairScore = TRUE)
     ## getPairScore(BT)
-
+    
     expect_equal(as.double(BT@count.favorable),c(0,1))
     expect_equal(as.double(BT@count.unfavorable),c(0,1))
     expect_equal(as.double(BT@count.neutral),c(4,2))
@@ -184,8 +181,8 @@ test_that("check mixed - 2 Binary",{
 ## ** favorable
 test_that("check favorable - continous",{
     ## one pair
-    data <- data.frame(size = c(1,0), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1), data = data)
+    data <- data.frame(size = c(1,0), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1), data = data)
     expect_equal(as.double(BT@count.favorable),1)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -193,7 +190,7 @@ test_that("check favorable - continous",{
 
     ## several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1), data = data2)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1), data = data2)
     expect_equal(as.double(BT@count.favorable),4)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -201,7 +198,7 @@ test_that("check favorable - continous",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(4,4))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(0,0))
@@ -211,8 +208,8 @@ test_that("check favorable - continous",{
 ## ** unfavorable
 test_that("check unfavorable - continous",{
     ## one pair
-    data <- data.frame(size = c(-1,0), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1), data = data)
+    data <- data.frame(size = c(-1,0), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),1)
     expect_equal(as.double(BT@count.neutral),0)
@@ -220,7 +217,7 @@ test_that("check unfavorable - continous",{
 
     ## several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1), data = data2)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),4)
     expect_equal(as.double(BT@count.neutral),0)
@@ -228,7 +225,7 @@ test_that("check unfavorable - continous",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(4,4))
     expect_equal(as.double(BT@count.neutral),c(0,0))
@@ -238,9 +235,9 @@ test_that("check unfavorable - continous",{
 ## ** neutral
 test_that("check neutral - continous",{
     ## one pair, 0 threshold
-    data <- data.frame(size = c(1,1), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 0), data=data)
-    BT.bis <- BuyseTest(Treatment ~ continuous(size), data=data)
+    data <- data.frame(size = c(1,1), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 0), data=data)
+    BT.bis <- BuyseTest(treatment ~ continuous(size), data=data)
     expect_equal(BT.bis,BT)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
@@ -249,7 +246,7 @@ test_that("check neutral - continous",{
 
     ## several pairs, 0 threshold
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1), data = data2)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),4)
@@ -257,15 +254,15 @@ test_that("check neutral - continous",{
 
     ## with strata, 0 threshold
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 1) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 1) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
     expect_equal(as.double(BT@count.uninf),c(0,0))
 
     ## 1 pair, non 0 threshold 
-    data <- data.frame(size = c(1,0), Treatment = c(1,0))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 2), data=data)
+    data <- data.frame(size = c(1,0), treatment = c(1,0))
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 2), data=data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),1)
@@ -273,7 +270,7 @@ test_that("check neutral - continous",{
 
     ## several pairs, non 0 threshold
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 2), data = data2)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 2), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),4)
@@ -281,7 +278,7 @@ test_that("check neutral - continous",{
 
     ## with strata, non 0 threshold
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 2) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 2) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
@@ -290,8 +287,8 @@ test_that("check neutral - continous",{
 
 ## ** NA as uninformative
 test_that("check NA - continuous",{
-    data <- data.frame(size = c(NA, 1, 1), Treatment = c(1, 1, 0))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 0), data = data)
+    data <- data.frame(size = c(NA, 1, 1), treatment = c(1, 1, 0))
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 0), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),1)
@@ -299,7 +296,7 @@ test_that("check NA - continuous",{
 
     ## more pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 0), data = data2)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 0), data = data2)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),4)
@@ -307,7 +304,7 @@ test_that("check NA - continuous",{
 
     ## with strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ continuous(size, threshold = 0) + strata, data = data3)
+    BT <- BuyseTest(treatment ~ continuous(size, threshold = 0) + strata, data = data3)
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
@@ -318,8 +315,8 @@ test_that("check NA - continuous",{
 ## ** favorable
 test_that("check favorable - time to event",{
     ## 0 threshold, 1 pair
-    data <- data.frame(time = c(1,0), Treatment = c(1,0), status = 1)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data)
+    data <- data.frame(time = c(1,0), treatment = c(1,0), status = 1)
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data)
     expect_equal(as.double(BT@count.favorable),1)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -327,7 +324,7 @@ test_that("check favorable - time to event",{
 
     ## 0 threshold, several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data2)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data2)    
     expect_equal(as.double(BT@count.favorable),4)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -335,14 +332,14 @@ test_that("check favorable - time to event",{
 
     ## 0 threshold, strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status) + strata, data = data3)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status) + strata, data = data3)    
     expect_equal(as.double(BT@count.favorable),c(4,4))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(0,0))
     expect_equal(as.double(BT@count.uninf),c(0,0))
 
     ## 1 threshold, strata
-    BT <- BuyseTest(Treatment ~ tte(time, threshold = 1, censoring = status) + strata, data = data3)    
+    BT <- BuyseTest(treatment ~ tte(time, threshold = 1, censoring = status) + strata, data = data3)    
     expect_equal(as.double(BT@count.favorable),c(4,4))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(0,0))
@@ -352,8 +349,8 @@ test_that("check favorable - time to event",{
 ## ** unfavorable
 test_that("check unfavorable - time to event",{
     ## 0 threshold, 1 pair
-    data <- data.frame(time = c(0,1), Treatment = c(1,0), status = 1)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data)
+    data <- data.frame(time = c(0,1), treatment = c(1,0), status = 1)
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),1)
     expect_equal(as.double(BT@count.neutral),0)
@@ -361,7 +358,7 @@ test_that("check unfavorable - time to event",{
 
     ## 0 threshold, several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data2)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data2)    
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),4)
     expect_equal(as.double(BT@count.neutral),0)
@@ -369,14 +366,14 @@ test_that("check unfavorable - time to event",{
 
     ## 0 threshold strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status) + strata, data = data3)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status) + strata, data = data3)    
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(4,4))
     expect_equal(as.double(BT@count.neutral),c(0,0))
     expect_equal(as.double(BT@count.uninf),c(0,0))
     
     ## 1 threshold, strata
-    BT <- BuyseTest(Treatment ~ tte(time, threshold = 1, censoring = status) + strata, data = data3)    
+    BT <- BuyseTest(treatment ~ tte(time, threshold = 1, censoring = status) + strata, data = data3)    
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(4,4))
     expect_equal(as.double(BT@count.neutral),c(0,0))
@@ -386,8 +383,8 @@ test_that("check unfavorable - time to event",{
 ## ** neutral
 test_that("check neutral - time to event",{
     ## 0 threshold, 1 pair
-    data <- data.frame(time = c(1,1), Treatment = c(1,0), status = 1)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data)
+    data <- data.frame(time = c(1,1), treatment = c(1,0), status = 1)
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data)
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),1)
@@ -395,7 +392,7 @@ test_that("check neutral - time to event",{
 
     ## 0 threshold, several pairs
     data2 <- rbind(data, data)
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data2)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data2)    
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),4)
@@ -403,7 +400,7 @@ test_that("check neutral - time to event",{
 
     ## 0 threshold strata
     data3 <- rbind(cbind(data2, strata = 0), cbind(data2, strata = 1))
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status) + strata, data = data3)    
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status) + strata, data = data3)    
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
@@ -411,8 +408,8 @@ test_that("check neutral - time to event",{
     
     ## 1 threshold, strata
     data4 <- data3
-    data4[data4$Treatment==1,"time"] <- 2
-    BT <- BuyseTest(Treatment ~ tte(time, threshold = 3, censoring = status) + strata, data = data4)    
+    data4[data4$treatment==1,"time"] <- 2
+    BT <- BuyseTest(treatment ~ tte(time, threshold = 3, censoring = status) + strata, data = data4)    
     expect_equal(as.double(BT@count.favorable),c(0,0))
     expect_equal(as.double(BT@count.unfavorable),c(0,0))
     expect_equal(as.double(BT@count.neutral),c(4,4))
@@ -422,16 +419,17 @@ test_that("check neutral - time to event",{
 ## ** NA as uninformative
 test_that("check NA - time to event",{
     ## censored after the event in the other arm
-    data <- data.frame(time = c(2,1), Treatment = c(1,0), status = c(0,1))
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data)
+    data <- data.frame(time = c(2,1), treatment = c(1,0), status = c(0,1))
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status),
+                    data = data)
     expect_equal(as.double(BT@count.favorable),1)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
     expect_equal(as.double(BT@count.uninf),0)
 
     ## censored at the same time as the event in the other arm
-    data <- data.frame(time = c(1,2,1), Treatment = c(1,1,0), status = c(0,1,1))
-    BT <- BuyseTest(Treatment ~ tte(time, censoring = status), data = data)
+    data <- data.frame(time = c(1,2,1), treatment = c(1,1,0), status = c(0,1,1))
+    BT <- BuyseTest(treatment ~ tte(time, censoring = status), data = data)
     expect_equal(as.double(BT@count.favorable),2)
     expect_equal(as.double(BT@count.unfavorable),0)
     expect_equal(as.double(BT@count.neutral),0)
@@ -450,7 +448,7 @@ dt.2pairs <- data.table(id = 1:4,
 ## *** Gehan
 test_that("2 pairs - Gehan - no correction",{
     BT <- BuyseTest(treat ~ tte(time, threshold = 0, censoring = cens), data = dt.2pairs,
-                    method.tte="Gehan", correction.uninf = FALSE)
+                    scoring.rule = "Gehan", correction.uninf = FALSE)
   
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),2)
@@ -466,7 +464,7 @@ test_that("2 pairs - Gehan - no correction",{
 
 test_that("2 pairs - Gehan - correction",{
     BT <- BuyseTest(treat ~ tte(time, threshold = 0, censoring = cens), data = dt.2pairs,
-                    method.tte="Gehan", correction.uninf = TRUE)
+                    scoring.rule = "Gehan", correction.uninf = TRUE)
   
     expect_equal(as.double(BT@count.favorable),0)
     expect_equal(as.double(BT@count.unfavorable),4)
@@ -483,7 +481,7 @@ test_that("2 pairs - Gehan - correction",{
 ## *** Peron
 test_that("2 pairs - Peron - no correction",{
     BT <- BuyseTest(treat ~ tte(time, threshold = 0, censoring = cens), data = dt.2pairs,
-                    method.tte="Peron", correction.uninf = FALSE)
+                    scoring.rule = "Peron", correction.uninf = FALSE)
   
     ## different survival curve per groups (denoting S survival time and T group)
     ## P[T>=t|T=0,S>=10] = 1 (t=<12), 0 (t>12)
@@ -510,7 +508,7 @@ test_that("2 pairs - Peron - no correction",{
 
 test_that("2 pairs - Peron - correction",{
     BT <- BuyseTest(treat ~ tte(time, threshold = 0, censoring = cens), data = dt.2pairs,
-                    method.tte="Peron", correction.uninf = TRUE)
+                    scoring.rule = "Peron", correction.uninf = TRUE)
   
     ## different survival curve per groups (denoting S survival time and T group)
     ## P[T>=t|T=0,S>=10] = 1 (t=<12), 0 (t>12)
@@ -554,12 +552,12 @@ df.all <- as.data.frame(M.all)
 test_that("Peron - predictible events",{
     df.all$trt <- abs(df.all$trt)
     BT <- BuyseTest(trt ~ tte(time, threshold = 0, censoring = status), data = df.all,
-                    method.tte="Peron", correction.uninf = FALSE)
+                    scoring.rule="Peron", correction.uninf = FALSE)
     expect_equal(as.double(BT@Delta.netBenefit),1)
 
     df.all$trt <- -abs(df.all$trt)
     BT <- BuyseTest(trt ~ tte(time, threshold = 0, censoring = status), data = df.all,
-                    method.tte="Peron", correction.uninf = FALSE)
+                    scoring.rule="Peron", correction.uninf = FALSE)
     expect_equal(as.double(BT@Delta.netBenefit),-1)
 
 })
