@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: apr 30 2018 (23:45) 
 ## Version: 
-## Last-Updated: okt 30 2018 (17:22) 
+## Last-Updated: nov  8 2019 (11:13) 
 ##           By: Brice Ozenne
-##     Update #: 97
+##     Update #: 109
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -18,9 +18,10 @@
 if(FALSE){
     library(testthat)
     library(BuyseTest)
+    library(data.table)
 }
 
-context("Check that method.tte = corrected  in BuyseTest is working correctly \n")
+context("Check that scoring.rule = corrected  in BuyseTest is working correctly \n")
 
 ## * settings
 BuyseTest.options(check = TRUE,
@@ -37,7 +38,7 @@ df <- data.frame("survie" = c(2.1, 4.1, 6.1, 8.1, 4, 6, 8, 10),
 test_that("1 TTE endpoint - Gehan (no correction)", {
     Gehan <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                        data = df,
-                       method.tte = "Gehan", correction.uninf = FALSE)
+                       scoring.rule = "Gehan", correction.uninf = FALSE)
 
     expect_equal(as.double(Gehan@count.favorable), c(9,0))
     expect_equal(as.double(Gehan@count.unfavorable), c(2,0))
@@ -58,8 +59,9 @@ test_that("1 TTE endpoint - Gehan (correction at the pair level)", {
     ## survival first    
     GehanC <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                         data = df, 
-                        method.tte = "Gehan", correction.uninf = TRUE)
+                        scoring.rule = "Gehan", correction.uninf = TRUE)
     ## getPairScore(GehanC)
+    ## summary(GehanC)
     
     expect_equal(as.double(GehanC@count.favorable), c(12,0))
     expect_equal(as.double(GehanC@count.unfavorable), c(2+2/3,0))
@@ -80,7 +82,7 @@ test_that("1 TTE endpoint - Gehan (correction IPCW)", {
     ## survival first    
     GehanC <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                         data = df, 
-                        method.tte = "Gehan", correction.uninf = 2)
+                        scoring.rule = "Gehan", correction.uninf = 2)
 
     factor <- 16/12 ## n.pairs/(n.pairs-n.uninf)
     expect_equal(as.double(GehanC@count.favorable), c(9*factor,0))
@@ -98,7 +100,7 @@ test_that("1 TTE endpoint - Gehan (correction IPCW)", {
     ## survival second
     GehanC2 <- BuyseTest(group ~  cont(score) + tte(survie, censoring = event, threshold = 1),
                          data = df, 
-                         method.tte = "Gehan", correction.uninf = 2)
+                         scoring.rule = "Gehan", correction.uninf = 2)
     
     expect_equal(GehanC@count.favorable[1], GehanC2@count.favorable[2])
     expect_equal(GehanC@count.unfavorable[1], GehanC2@count.unfavorable[2])
@@ -118,7 +120,7 @@ test_that("1 TTE endpoint - Peron (no correction)", {
 
     Peron <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                        data = df, 
-                       method.tte = "Peron", correction.uninf = FALSE)
+                       scoring.rule = "Peron", correction.uninf = FALSE)
 
     ## summary(Peron, percentage = FALSE)
     expect_equal(as.double(Peron@count.favorable), c(10,0))
@@ -138,7 +140,7 @@ test_that("1 TTE endpoint - Peron (IPCW)", {
     ## survival first
     PeronC <- BuyseTest(group ~ tte(survie, censoring = event, threshold = 1) + cont(score),
                         data = df, 
-                        method.tte = "Peron", correction.uninf = 2)
+                        scoring.rule = "Peron", correction.uninf = 2)
 
     ## summary(PeronC, percentage = FALSE)
     factor <- PeronC@n.pairs/(PeronC@n.pairs-3) ## n.pairs/(n.pairs-n.uninf)
@@ -157,7 +159,7 @@ test_that("1 TTE endpoint - Peron (IPCW)", {
     ## survival second
     PeronC2 <- BuyseTest(group ~  cont(score) + tte(survie, censoring = event, threshold = 1),
                          data = df, 
-                         method.tte = "Peron", correction.uninf = 2)
+                         scoring.rule = "Peron", correction.uninf = 2)
     
     expect_equal(PeronC@count.favorable[1], PeronC2@count.favorable[2])
     expect_equal(PeronC@count.unfavorable[1], PeronC2@count.unfavorable[2])
@@ -188,7 +190,7 @@ dt[trt==1, Y2 := as.numeric(1-C)]
 
 ## table(dt$trt,dt$Y1,dt$Y2)
 
-test_that("2 TTE endpoint - IPW induces bias when censoring is correlated with 2nd endpoint", {
+test_that("2 endpoints - IPW induces bias when censoring is correlated with 2nd endpoint", {
     BT.all <- BuyseTest(trt ~ cont(Y1, threshold = 1) + bin(Y2), data = dt,
                         correction.uninf = 0, method.inference = "none")
     expect_equal(as.double(BT.all@count.favorable), c(0,4))
@@ -219,5 +221,34 @@ test_that("2 TTE endpoint - IPW induces bias when censoring is correlated with 2
 
 })
 
+## ** time to event variables
+set.seed(10)
+dt.sim <- simBuyseTest(n.T = 20,
+                       n.C = 20)
+test_that("2 TTE endpoints - check consistency across threshold when using corrections", {
+    e.BT2 <- BuyseTest(treatment ~ tte(eventtime,status,1)  + tte(eventtime,status,0.75) + tte(eventtime,status,0.5),
+                       correction.uninf = 1, data = dt.sim)
+    e.BT1 <- BuyseTest(treatment ~ tte(eventtime,status,0.5),
+                       correction.uninf = 1, data = dt.sim)
+    expect_equal(sum(e.BT2@count.favorable),e.BT1@count.favorable[1,1])
+    expect_equal(sum(e.BT2@count.unfavorable),e.BT1@count.unfavorable[1,1])
+    expect_equal(e.BT2@count.neutral[1,3],e.BT1@count.neutral[1,1])
+    expect_equal(e.BT2@count.uninf[1,3],e.BT1@count.uninf[1,1])
+
+    e.BT2 <- BuyseTest(treatment ~ tte(eventtime,status,1)  + tte(eventtime,status,0.75) + tte(eventtime,status,0.5),
+                       correction.uninf = 2, data = dt.sim)
+    e.BT1 <- BuyseTest(treatment ~ tte(eventtime,status,0.5),
+                       correction.uninf = 2, data = dt.sim)
+    expect_equal(sum(e.BT2@count.favorable),e.BT1@count.favorable[1,1])
+    expect_equal(sum(e.BT2@count.unfavorable),e.BT1@count.unfavorable[1,1])
+    expect_equal(e.BT2@count.neutral[1,3],e.BT1@count.neutral[1,1])
+    expect_equal(e.BT2@count.uninf[1,3],e.BT1@count.uninf[1,1])
+})
+
+test_that("TTE,cont,TTE endpoints - check consistency across threshold when using corrections", {
+    e.BT2 <- BuyseTest(treatment ~ tte(eventtime,status,1)  + cont(score,1) + tte(eventtime,status,0.5),
+                       correction.uninf = 1, data = dt.sim)
+    expect_equal(e.BT2@count.neutral[1,2],(e.BT2@count.favorable[1,3]+e.BT2@count.unfavorable[1,3]+e.BT2@count.neutral[1,3]))
+})
 ##----------------------------------------------------------------------
 ### test-BuyseTest-correctionTTE.R ends here
